<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About MystiQ</source>
        <translation>Despre MystiQ </translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informații</translation>
    </message>
    <message>
        <source>Translators</source>
        <translation>Traducători</translation>
    </message>
    <message>
        <source>Portable</source>
        <translation>Portabil</translation>
    </message>
    <message>
        <source>Compiled with Qt %1</source>
        <translation>Compilat cu Qt %1</translation>
    </message>
    <message>
        <source>Compiled with libnotify %1</source>
        <translation>Compilat cu libnotify %1</translation>
    </message>
    <message>
        <source>MystiQ Homepage: %1</source>
        <translation>Pagina acasă MystiQ: %1</translation>
    </message>
    <message>
        <source>Some audio-processing functionalities are provided by SoX.</source>
        <translation>Unele funcționalități de prelucrare audio sunt oferite de SoX.</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <extracomment>Spanish Language (Spain)</extracomment>
        <translation>Spaniolă (Spania) </translation>
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MystiQ is a GUI frontend for FFmpeg.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Developers:&lt;br&gt; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application Name:&lt;br&gt; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <extracomment>Swedish Language (Sweden)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <extracomment>Japanese Language (Japan)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <extracomment>German Language (Germany)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <extracomment>Italian Language (Italy)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License version 3.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <extracomment>Turkish Language (Turkey)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Many people have contributed translations. You can also help translate the MystiQ Video Converter into your own language. Visit </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> and join a translation team.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hungarian (Hungary)</source>
        <extracomment>Hungarian Language (Hungary)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <extracomment>Russian Language (Russia)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Collaborators:&lt;br&gt; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some features of MystiQ Video Converter have been inspired by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Galician (Galicia)</source>
        <extracomment>Galician Language (Galicia)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Icons Theme:&lt;br&gt; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Indonesian (Indonesia)</source>
        <extracomment>Indonesian Language (Indonesia)</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutFFmpegDialog</name>
    <message>
        <source>About FFmpeg</source>
        <translation>Despre FFmpeg</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Available Codecs</source>
        <translation>Codecuri disponibile</translation>
    </message>
    <message>
        <source>FFmpeg is a complete, cross-platform solution to record, convert and stream audio and video. It includes libavcodec - the leading audio/video codec library.</source>
        <extracomment>ffmpeg description</extracomment>
        <translation>FFmpeg este un sistem complet, soluție cross-platform pentru a înregistra, converti fluxuri audio și video. Acesta include libavcodec - bibliotecă codec lider în materie.</translation>
    </message>
    <message>
        <source>FFmpeg is free software licensed under the LGPL or GPL.</source>
        <translation>FFmpeg este un software gratuit sub licența LGPL sau GPL.</translation>
    </message>
    <message>
        <source>Please visit %1 for more information.</source>
        <translation>Te rog vizitează %1 pentru mai multe informații.</translation>
    </message>
</context>
<context>
    <name>AddTaskWizard</name>
    <message>
        <source>Add Tasks</source>
        <translation>Adaugă sarcini</translation>
    </message>
    <message>
        <source>Files to be converted</source>
        <translation>Fișierele care urmează să fie convertite</translation>
    </message>
    <message>
        <source>Add files.</source>
        <translation>Adaugă fișiere.</translation>
    </message>
    <message>
        <source>Remove selected files.</source>
        <translation>Elimină fișierele selectate.</translation>
    </message>
    <message>
        <source>Output Settings</source>
        <translation>Setări de ieșire</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editare</translation>
    </message>
    <message>
        <source>Auto adjust output bitrate to reduce output file size.</source>
        <translation>Ajustare automată a ratei de biți de ieșire pentru a reduce dimensiunea fișierului rezultat.</translation>
    </message>
    <message>
        <source>Auto Adjust Audio Bitrate</source>
        <translation>Ajustare automată a ratei de biți audio</translation>
    </message>
    <message>
        <source>Preset</source>
        <translation>Presetate</translation>
    </message>
    <message>
        <source>Convert to</source>
        <translation>Conversie în</translation>
    </message>
    <message>
        <source>Output Path</source>
        <translation>Calea de ieșire</translation>
    </message>
    <message>
        <source>Select &amp;folder</source>
        <translation>Selectează &amp;dosar</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Răsfoiește</translation>
    </message>
    <message>
        <source>Create &amp;new folder in source folder</source>
        <extracomment>Create a new folder (e.g. mystiq_output) in the folder containing the input files. Put the output files in the newly created folder.</extracomment>
        <translation>Creează un nou dosar în dosarul sursă</translation>
    </message>
    <message>
        <source>Folder Name</source>
        <translation>Nume dosar</translation>
    </message>
    <message>
        <source>Output to &amp;source folder</source>
        <extracomment>put the output files in the same folder as the input files</extracomment>
        <translation>Scrie în dosarul &amp;sursă</translation>
    </message>
    <message>
        <source>Please select at least one file.</source>
        <translation>Selectează cel puțin un fișier.</translation>
    </message>
    <message>
        <source>Select Files</source>
        <extracomment>This text is the title of an openfile dialog.</extracomment>
        <translation>Selectează fișiere</translation>
    </message>
    <message>
        <source>Multimedia</source>
        <translation>Multimedia</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Toate fișierele</translation>
    </message>
    <message>
        <source>Select Directory</source>
        <extracomment>This text is the title of an open directory dialog.</extracomment>
        <translation>Selectează dosarul</translation>
    </message>
    <message>
        <source>Searching for files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some files could not be found.</source>
        <translation>Unele fișiere nu au putut fi găsite.</translation>
    </message>
    <message>
        <source>Folder does not exist. Create a new folder?</source>
        <translation>Dosarul nu există. Creezi un dosar nou?</translation>
    </message>
    <message>
        <source>Failed to create folder. Please select another output folder.</source>
        <translation>Crearea dosarului a eșuat. Te rog selectează un alt dosar de ieșire.</translation>
    </message>
    <message>
        <source>Add Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation type="unfinished">Golire listă</translation>
    </message>
</context>
<context>
    <name>ConversionParameterDialog</name>
    <message>
        <source>Conversion Parameters</source>
        <translation>Parametrii de conversie</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Disable Audio</source>
        <translation>Dezactivează audio</translation>
    </message>
    <message>
        <source>Audio Options</source>
        <translation>Opțiuni audio</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation>Rată de eșantionare</translation>
    </message>
    <message>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation>Rată de biți</translation>
    </message>
    <message>
        <source>(auto)</source>
        <translation>(auto)</translation>
    </message>
    <message>
        <source>kb/s</source>
        <translation>kb/s</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Canale</translation>
    </message>
    <message>
        <source>Volume</source>
        <translation>Volum</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Disable Video</source>
        <translation>Dezactivează video</translation>
    </message>
    <message>
        <source>Video Options</source>
        <translation>Opțiuni video</translation>
    </message>
    <message>
        <source>Same Quantizer as Source</source>
        <translation>Quantizer Identic cu al Sursei </translation>
    </message>
    <message>
        <source>Deinterlace</source>
        <translation>Deinterlace</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Lățime</translation>
    </message>
    <message>
        <source> px</source>
        <translation>px</translation>
    </message>
    <message>
        <source>Height</source>
        <translation>Înălțime</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>Decupează</translation>
    </message>
    <message>
        <source>Time</source>
        <extracomment>time-related options (speed, length)</extracomment>
        <translation>Timp</translation>
    </message>
    <message>
        <source>Cutting</source>
        <extracomment>video time cutting: options for begin time and end time</extracomment>
        <translation>Tăiere</translation>
    </message>
    <message>
        <source>Cut</source>
        <comment>Cut video; select a range to convert</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>&amp;Previzualizare</translation>
    </message>
    <message>
        <source>Scaling</source>
        <extracomment>time scaling, changing the speed of the output file</extracomment>
        <translation>Scalarea</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Viteză</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Avansate</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg</translation>
    </message>
    <message>
        <source>Additional FFmpeg Options</source>
        <translation>Opțiuni suplimentare FFmpeg</translation>
    </message>
    <message>
        <source>Copy Audio (Do not re-encode)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert Subtitle if Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Video (Do not re-encode)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>qrc:/qml/main.qml</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Extra Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video to Black and White</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vertical Flip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal Flip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate 90 degrees clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate 90 degrees counterclockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate 180 degrees</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3D Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Blue Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Dubois</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green Magenta Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Half Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yellow Blue Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Cyan Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green Magenta Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red Green Gray Monochromatic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConvertList</name>
    <message>
        <source>Cancel</source>
        <extracomment>Cancel the operation of adding new tasks</extracomment>
        <translation>Renunță</translation>
    </message>
    <message>
        <source>Adding files (%1/%2)</source>
        <extracomment>This text is the progress indicator of adding multiple tasks. %1 is the number of files that are already added. %2 is the total number of files.</extracomment>
        <translation>Adăugare fișiere (%1/%2)</translation>
    </message>
    <message>
        <source>Some files are not recognized by the converter.</source>
        <translation>Unele fișiere nu sunt recunoscute de către convertor.</translation>
    </message>
    <message>
        <source>New File Name</source>
        <translation>Numele noului fișier</translation>
    </message>
    <message>
        <source>Please input the new name for the output file.</source>
        <translation>Vă rugăm să introduceți noul nume a fișierului în ieșire</translation>
    </message>
    <message>
        <source>Output Directory</source>
        <translation>Directorul de Ieșire</translation>
    </message>
    <message>
        <source>Error Message from FFmpeg:

</source>
        <translation>Mesajul de eroare de la FFmpeg:

</translation>
    </message>
    <message>
        <source>Drag and drop files here to add tasks.</source>
        <translation>Trage fișiere aici pentru a adăuga sarcini.</translation>
    </message>
    <message>
        <source>Hide &quot;%1&quot;</source>
        <extracomment>Hide a column in the list. For example, the text maybe &apos;Hide &quot;Duration&quot;&apos;. The two &quot; are quotation marks in English, you may replace it with local quotation marks.</extracomment>
        <translation>Ascunde &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Restore All Columns</source>
        <translation>Restaurarea tuturor coloanelor</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Sursă</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Destinație</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durată</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>Dimensiune</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <extracomment>Audio</extracomment>
        <translation>Rată de eșantionare</translation>
    </message>
    <message>
        <source>Audio Bitrate</source>
        <translation>Rată de biți audio</translation>
    </message>
    <message>
        <source>Channels</source>
        <extracomment>Audio</extracomment>
        <translation>Canale</translation>
    </message>
    <message>
        <source>Audio Codec</source>
        <translation>Codec audio</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensiuni</translation>
    </message>
    <message>
        <source>Video Bitrate</source>
        <translation>Rată de biți video</translation>
    </message>
    <message>
        <source>Framerate</source>
        <extracomment>Video</extracomment>
        <translation>Framerate</translation>
    </message>
    <message>
        <source>Video Codec</source>
        <translation>Codec video</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Progres</translation>
    </message>
    <message>
        <source>%1 Hz</source>
        <translation>%1 Hz</translation>
    </message>
    <message>
        <source>%1 kb/s</source>
        <translation>%1 kb/s</translation>
    </message>
    <message>
        <source>%1 fps</source>
        <translation>%1 fps</translation>
    </message>
    <message>
        <source>Removing tasks...</source>
        <extracomment>Remove files from the tasklist</extracomment>
        <translation>Eliminare sarcini...</translation>
    </message>
    <message>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <translation>TiB</translation>
    </message>
    <message>
        <source>B</source>
        <extracomment>Bytes</extracomment>
        <translation>B</translation>
    </message>
    <message>
        <source>File Exists</source>
        <translation>Fișierul există</translation>
    </message>
    <message>
        <source>%1 already exists on disk or in the task list. Still use this name as the output filename?</source>
        <translation>%1 există deja pe disc sau în lista de activități. Folosesc oricum acest nume ca numele fișierului de ieșire?</translation>
    </message>
    <message>
        <source>Remove Task</source>
        <translation>Elimină sarcina</translation>
    </message>
    <message>
        <source>Cannot remove a task while it is in progress.</source>
        <translation>Nu se poate șterge o sarcină în timp ce este în curs de desfășurare.</translation>
    </message>
    <message>
        <source>Finished</source>
        <extracomment>The text to be displayed on the progress bar when a conversion finishes</extracomment>
        <translation>Terminat</translation>
    </message>
    <message>
        <source>Failed</source>
        <extracomment>The text to be displayed on the progress bar when a conversion fails</extracomment>
        <translation>A eșuat</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <extracomment>%1 is the error message</extracomment>
        <translation>Eroare: %1</translation>
    </message>
</context>
<context>
    <name>ExtraTranslations</name>
    <message>
        <source>Convert between media file formats</source>
        <translation>Converteşte formatele de fișiere media</translation>
    </message>
    <message>
        <source>Media Converter</source>
        <translation>Media Converter</translation>
    </message>
</context>
<context>
    <name>HelpMystiQDialog</name>
    <message>
        <source>User Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Fira Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:18pt; font-weight:600;&quot;&gt;MystiQ User&apos;s Manual&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/mystiq_96x96.png&quot; style=&quot;float: left;&quot; /&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is a cross platform application. This application has as its sole objective the conversion of audio and video files to multiple formats. As a distinctive feature, MystiQ is an open source project, which means that the source code will always be available and everyone who wishes to contribute to the development is welcome.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter is free: you can redistribute it and / or modify it under the terms GNU (General Public License) published by the Free Software Foundation. MystiQ Video Converter is freely distributed with the sole purpose of being a useful application to your needs, but WITHOUT NO WARRANTY, even if its use is COMMERCIAL or MERELY A PARTICULAR PURPOSE See the GPL v3 license for more details. This application includes an English copy of the Software distribution license.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The essential idea of ​​the development team is to provide a friendly and simple user interface. The simple is the essence of MystiQ, which means that it is not our objective to add features that complicate the operation of the application.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Currently MystiQ is mainly developed in C ++ taking advantage of the Qt5 graphic libraries. In the FFmpeg backend he is in charge of converting between formats, so we can say that MystiQ is simply a graphical interface for FFmpeg.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ currently allows you to convert to most existing video formats, as well as make it possible to extract audio and convert between audio formats. It also includes a small tool to trim videos based on the duration of these.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;MystiQ Video Converter currently supports the following audio and video formats:&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Audio: mp3 m4a 3g2 ogg wav wma  ac3 ra ape flac opus&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- Video: avi vfw divx mpg mpeg m1v m2v mpv dv 3gp mov mp4 m4v mqv dat vcd ogg ogm ogv asf wmv bin iso vob mkv nsv ram flv rm swf ts rmvb dvr-ms m2t m2ts rec mts webm dv&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot1.png&quot; /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Toolbar&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;In the upper part of the main window of the application we will find the toolbar with the following buttons:&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot2.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;ul style=&quot;margin-top: 0px; margin-bottom: 0px; margin-left: 0px; margin-right: 0px; -qt-list-indent: 1;&quot;&gt;&lt;li style=&quot;&quot; style=&quot; margin-top:12px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Add Files:&lt;/span&gt; &lt;span style=&quot; font-size:12pt;&quot;&gt;Opens a dialog to select the video files you want to convert. Once selected, they are placed in the List of Conversion Tasks&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Start: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Start conversion process from the list of loaded items&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Stop: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Stops the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the process of converting an item&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Retry All:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Retry the conversion process of all items in the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Selected:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove a selected item from the list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Remove Completed:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the list that have completed the conversion process&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Clear List:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Remove all items from the conversion list&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Open Output Folder: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;From the system file manager open the folder that contains the converted files&lt;/span&gt;&lt;/li&gt;
&lt;li style=&quot; font-size:12pt;&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Power Options:&lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;  &lt;/span&gt;Choose whether to shut down, suspend or hibernate the computer when completing the conversion process of all items in the list&lt;/li&gt;&lt;/ul&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;br /&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Audio Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot3.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Audio:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding sound.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Copy audio (do not recode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the audio from the source file. The resulting file will have the same sound parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Sample Rate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; In audio production, a sample rate (or &amp;quot;sampling rate&amp;quot;) defines how many times per second a sound is sampled. Technically speaking, it is the frequency of samples used in a digital recording.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Bitrate:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; It&apos;s the bit rate or data that is processed per unit of time. The average bitrate for an MP3 file is 128 kbits per second or kbps.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Channels: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the passage way a signal or data is transported. In case of audio files, it&apos;s the passage or communication channel in which a sound signal is transported from the player source to the speaker. An audio file can contain one, two or even more Channels.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Volume: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Allows you to configure the maximum volume of the destination file taking as a match the volume level of the source file.&lt;/span&gt;&lt;/p&gt;
&lt;hr /&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;Video Options&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;img src=&quot;:/app/icons/screenshot4.png&quot; /&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Insert Subtitle if Available: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;By checking this option, the application will verify if a subtitle file of the same name is found in the same location of the source file, if found, it will embed it in the resulting file. It is currently compatible with subtitles in SRT, SSA, ASS and SUB format.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Disable Video:&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to obtain a resulting file excluding video.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Copy Video (Do not re-encode):&lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt; Allows you to convert without processing the video from the source file. The resulting file will have the same video parameters as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Video to Black and White: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It allows to obtain a video file is grayscale.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Flip and Rotate options: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;The resulting file will be rotated or flipped in the direction chosen.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;- &lt;/span&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Deinterlace: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s the process of converting interlaced video, such as common analog television signals or 1080i format HDTV signals, into a non-interlaced form. An interlaced video frame consists of two sub-fields taken in sequence, each sequentially scanned at odd, and then even, lines of the image sensor.&lt;/span&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;- Same Quantizer as source: &lt;/span&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;It&apos;s involved in image processing, is a lossy compression technique achieved by compressing a range of values to a single quantum value. Checking this option the resulting file will have the same deinterlacing as the source file.&lt;/span&gt;&lt;/p&gt;
&lt;p align=&quot;center&quot; style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px; font-size:12pt;&quot;&gt;&lt;br /&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>InteractiveCuttingDialog</name>
    <message>
        <source>Cutting</source>
        <comment>Cutting as in &quot;cutting video&quot;</comment>
        <translation>Tăiere</translation>
    </message>
    <message>
        <source>Mark as Begin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seek to Begin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play Selection</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mark as End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Seek to End</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Start conversion process.</source>
        <translation>Începe procesul de conversie.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fișier</translation>
    </message>
    <message>
        <source>&amp;Convert</source>
        <translation>&amp;Conversie</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editare</translation>
    </message>
    <message>
        <source>&amp;Add Files</source>
        <translation>&amp;Adaugă fișiere</translation>
    </message>
    <message>
        <source>Add files for conversion.</source>
        <translation>Adaugă fișiere pentru conversie.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>Term&amp;ină</translation>
    </message>
    <message>
        <source>Exit the program.</source>
        <translation>Ieșire din program.</translation>
    </message>
    <message>
        <source>S&amp;top</source>
        <translation>S&amp;top</translation>
    </message>
    <message>
        <source>Stop conversion process.</source>
        <translation>Oprirea procesului de conversie.</translation>
    </message>
    <message>
        <source>Set &amp;Parameters</source>
        <translation>Setare &amp;parametrii</translation>
    </message>
    <message>
        <source>Set Parameters</source>
        <extracomment>Edit output file parameters.</extracomment>
        <translation>Setare parametrii</translation>
    </message>
    <message>
        <source>Edit conversion parameters of selected files.</source>
        <translation>Editarea parametrilor de conversie ale fișierelor selectate.</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Despre &amp;Qt</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Despre Qt </translation>
    </message>
    <message>
        <source>&amp;Open Output Folder</source>
        <translation>&amp;Deschide Folderul de Ieşire</translation>
    </message>
    <message>
        <source>Open output folder of the selected file.</source>
        <translation>Deschide dosarul de ieșire al fișierului selectat.</translation>
    </message>
    <message>
        <source>About &amp;FFmpeg</source>
        <translation>Despre &amp; FFmpeg </translation>
    </message>
    <message>
        <source>About FFmpeg</source>
        <translation>Despre FFmpeg</translation>
    </message>
    <message>
        <source>&amp;Remove Selected</source>
        <extracomment>remove selected (tasks, items)</extracomment>
        <translation>&amp;Eliminarea celor Selecționate</translation>
    </message>
    <message>
        <source>Remove all selected items in the list.</source>
        <translation>Eliminarea tuturor elementelor selectate din lista.</translation>
    </message>
    <message>
        <source>R&amp;emove Completed</source>
        <extracomment>remove completed (task, items)</extracomment>
        <translation>E&amp;liminarea celor Finalizate</translation>
    </message>
    <message>
        <source>Remove Completed Items</source>
        <translation>Eliminarea Elemente Finalizate</translation>
    </message>
    <message>
        <source>Remove all completed items in the list.</source>
        <translation>Elimina toate elementele finalizate din listă.</translation>
    </message>
    <message>
        <source>Clear List</source>
        <translation>Golire listă</translation>
    </message>
    <message>
        <source>Remove all items in the list.</source>
        <translation>Eliminarea tuturor elementelor din lista.</translation>
    </message>
    <message>
        <source>&amp;Retry</source>
        <translation>&amp;Reîncercați</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>Reîncercați</translation>
    </message>
    <message>
        <source>Retry selected tasks.</source>
        <translation>Reîncercați elementele selectate</translation>
    </message>
    <message>
        <source>Retry &amp;All</source>
        <translation>Reîncercați  &amp;Toate</translation>
    </message>
    <message>
        <source>Retry all tasks.</source>
        <translation>Reîncercați toate sarcinile. </translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation>&amp;Opțiuni</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opțiuni </translation>
    </message>
    <message>
        <source>About This Program</source>
        <translation>Despre Acest Program</translation>
    </message>
    <message>
        <source>Change Output &amp;Filename</source>
        <translation>Modificarea &amp;Numele Fișierului  În Ieșire</translation>
    </message>
    <message>
        <source>Change the output filename of the selected item.</source>
        <translation>Modificarea fișierului de ieșire a elementului selectat. </translation>
    </message>
    <message>
        <source>Change Output &amp;Directory</source>
        <translation>Modificarea &amp;Directorului de Ieșire</translation>
    </message>
    <message>
        <source>Change the output directory of the selected items.</source>
        <translation>Schimbați directorul de ieșire ale elementelor selectate.</translation>
    </message>
    <message>
        <source>Show Error &amp;Message</source>
        <translation>Afişează &amp;Mesajul de Eroare</translation>
    </message>
    <message>
        <source>Check For &amp;Updates</source>
        <translation>Verifică pentru act&amp;ualizări</translation>
    </message>
    <message>
        <source>Cut</source>
        <extracomment>Cut video file (select a time range to conert)</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All tasks have finished.</source>
        <translation>Toate sarcinile s-au terminat.</translation>
    </message>
    <message>
        <source>Nothing to convert.</source>
        <translation>Nimic de convertit.</translation>
    </message>
    <message>
        <source>Conversion is still in progress. Abort?</source>
        <translation>Conversia este încă în curs. Abandonați?</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer (completely poweroff)</extracomment>
        <translation>Shutdown</translation>
    </message>
    <message>
        <source>Shutdown when all tasks are done.</source>
        <translation>Shutdown atunci când toate sarcinile au fost finalizate.</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Suspendare</translation>
    </message>
    <message>
        <source>Suspend when all tasks are done.</source>
        <translation>Suspendare atunci când toate sarcinile au fost efectuate.</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Hibernare</translation>
    </message>
    <message>
        <source>Hibernate when all tasks are done.</source>
        <translation>Hibernare când toate sarcinile sunt efectuate. </translation>
    </message>
    <message>
        <source>This program is going to check for updates online. Do you allow this program to use the Internet to check for updates?</source>
        <translation>Acest program va căuta actualizări pe internet. Îi permiți acestui program să folosească internetul pentru a verifica dacă există actualizări?</translation>
    </message>
    <message>
        <source>Failed to load preset file. The application will quit now.</source>
        <translation>Imposibilă încărcarea fișierului presetat. Aplicaţia se va închide acum.</translation>
    </message>
    <message>
        <source>Elapsed Time: %1 h %2 m %3 s</source>
        <translation>Timp scurs: %1 h %2 m %3 s</translation>
    </message>
    <message>
        <source>MystiQ Media Converter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F5</source>
        <translation type="unfinished">F5</translation>
    </message>
    <message>
        <source>Clear &amp;List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About MystiQ</source>
        <translation type="unfinished">Despre MystiQ </translation>
    </message>
    <message>
        <source>Poweroff</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Manual</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F1</source>
        <translation type="unfinished">F1</translation>
    </message>
    <message>
        <source>&amp;Report Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Donate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conversion finished successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Conversion failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Support MystiQ</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MystiQ needs you</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MystiQ is free software. However the development requires a lot of time and a lot of work. In order to keep developing MystiQ with new features we need your help. Please consider to support the MystiQ project by sending a donation. &lt;b&gt;Even the smallest amount will help a lot.&lt;/b&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reporting bugs from MystiQ </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your comment:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MystiQ is Converting %1/%2</source>
        <extracomment>Converting the %1-th file in %2 files. %2 is the number of files.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MystiQ Video Converter</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Translate Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report Bugs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>We need your feedback</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Github</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MystiQ Video Converter development team needs users who use the application to help detect errors. If you find an error and report it to our team, it will help speed up the correction process. Therefore, you can be part of our development team even if you are not a developer. To report an error, you can send us an email with the detailed description of it or you can enter Github and describe the issue (in this case you must have a GitHub Account).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gitter</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaConverter</name>
    <message>
        <source> FFmpeg or FFprobe %1 have not been found in the system. Please consider installing them before running MystiQ</source>
        <extracomment>%1 is a computer program</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaPlayerWidget</name>
    <message>
        <source>...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opțiuni </translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>Verifică pentru actualizări la pornirea programului</translation>
    </message>
    <message>
        <source>Automatically start conversion after adding files to the list.</source>
        <translation>Pornește automat conversia după adăugarea fișierelor în listă.</translation>
    </message>
    <message>
        <source>Start conversion automatically</source>
        <translation>Pornește conversia automat</translation>
    </message>
    <message>
        <source>FFmpeg</source>
        <translation>FFmpeg </translation>
    </message>
    <message>
        <source>Number of threads to use in conversion</source>
        <translation>Numărul de  threaduri utilizate în conversie</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Hide output formats that are not available in the current ffmpeg installation. It is recommended to turn this option on unless you are sure that MystiQ has failed to detect available formats. (requires restarting MystiQ to take effect)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ascunde formatele de ieșire care nu sunt disponibile în instalarea curentă FFMPEG. Este recomandat să dezactivați această opțiune numai în cazul în care sunteți sigur că MystiQ nu a reușit să detecteze corect formatele disponibile. (Necesită repornirea MystiQ )&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Hide unavailable formats (requires restarting)</source>
        <translation>Ascunde formatele indisponibile (necesită repornirea)</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Instrumente </translation>
    </message>
    <message>
        <source>You have to restart MystiQ for the changes to take effect.</source>
        <translation>Trebuie să reporniți MystiQ pentru ca modificările să aibă efect.</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nume </translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comandă </translation>
    </message>
</context>
<context>
    <name>PoweroffDialog</name>
    <message>
        <source>MystiQ</source>
        <translation>MystiQ </translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anulare </translation>
    </message>
    <message>
        <source>Shutdown immediately</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>Shutdown imediat</translation>
    </message>
    <message>
        <source>Suspend immediately</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Suspendare imediată</translation>
    </message>
    <message>
        <source>Hibernate immediately</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Hibernare imediată</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <extracomment>Shutdown the computer</extracomment>
        <translation>Shutdown</translation>
    </message>
    <message>
        <source>Suspend</source>
        <extracomment>Suspend the computer (sleep to ram, standby)</extracomment>
        <translation>Suspendare</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <extracomment>Hibernate the computer (sleep to disk, completely poweroff)</extracomment>
        <translation>Hibernare </translation>
    </message>
    <message>
        <source>Operation Failed: %1</source>
        <translation>Operație eșuată: %1</translation>
    </message>
    <message>
        <source>Shutting down in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Stingere în &lt;b&gt;%1&lt;/b&gt; secunde</translation>
    </message>
    <message>
        <source>Suspending in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Suspendare în &lt;b&gt;%1&lt;/b&gt; secunde </translation>
    </message>
    <message>
        <source>Hibernating in &lt;b&gt;%1&lt;/b&gt; seconds</source>
        <translation>Hibernare în &lt;b&gt;%1&lt;/b&gt; secunde</translation>
    </message>
</context>
<context>
    <name>PreviewDialog</name>
    <message>
        <source>Play Selected Range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Begin</source>
        <extracomment>noun, the beginning of the video</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <extracomment>noun, the end of the video</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play %1~%2</source>
        <extracomment>play the video from time %1 to time %2. %1 and %2 are time in hh:mm:ss format.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TimeRangeEdit</name>
    <message>
        <source>From Begin</source>
        <translation>De la început</translation>
    </message>
    <message>
        <source>To End</source>
        <translation>Până la capăt</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <source>Show &amp;Release Notes</source>
        <translation>A&amp;rată notele de lansare</translation>
    </message>
    <message>
        <source>Check for updates on program startup</source>
        <translation>Verifică pentru actualizări la pornirea programului</translation>
    </message>
    <message>
        <source>Downloading update information...</source>
        <translation>Se descarcă informațiile despre actualizare...</translation>
    </message>
    <message>
        <source>Cannot connect to server.</source>
        <translation>Nu se poate efectua conectarea la server.</translation>
    </message>
    <message>
        <source>Failed to parse the received data.</source>
        <translation>Interpretarea datelor primite a eșuat.</translation>
    </message>
    <message>
        <source>You are already using the latest version of MystiQ.</source>
        <translation>Deja folosești ultima versiune de MystiQ.</translation>
    </message>
    <message>
        <source>An unknown error has occurred.</source>
        <translation>A intervenit o eroare necunoscută.</translation>
    </message>
    <message>
        <source>A new version of MystiQ has been released!</source>
        <translation>A apărut o nouă versiune de MystiQ!</translation>
    </message>
    <message>
        <source>Version &lt;b&gt;%1&lt;/b&gt; is available at %2.</source>
        <extracomment>%1 is version number, %2 is the project homepage</extracomment>
        <translation>Versiunea &lt;b&gt;%1&lt;/b&gt; este disponibilă la %2.</translation>
    </message>
    <message>
        <source>You can download this version using the link:</source>
        <translation>Poți descărca această versiunea folosind legătura:</translation>
    </message>
    <message>
        <source>Check Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The current version you are using is newer than the release channel version.&lt;br&gt;Therefore, you are using the development channel.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
